==> ufpy-0.2.1.1.tar.gz: ufpy-0.2.1.1/ufpy/cmp.py <==
__all__ = (
    'cmp_generator',
    'Comparable',
)

from typing import Generic, Protocol, Type, TypeVar

T = TypeVar('T', bound=type)

def cmp_generator(t: Type[T]) -> Type[T]:
    '''
    Decorator for auto generate compare magic methods (`__eq__()`, `__ne__()`, `__lt__()`, `__le__()`, `__gt__()`, `__ge__()`).
    You should add `__cmp__()` method in your class. If your object more that other, `__cmp__()` should return positive number.
    If less that other, `__cmp__()` should return negative number. If equals, `__cmp__()` should return zero.
    
    `Note:`
    If you defined one of compare methods, they won't redefine.

    Example:
    ```py
    @cmp_generator
    class A:
        def __init__(self, num: int):
            self.num = num
        def __cmp__(self, other: int) -> int:
            return self.num - self.other
    
    a = A(2)
    print(a > 1) # True
    print(a < 2) # False
    print(a >= 3) # False
    print(a <= 4) # True
    ```
    
    Online docs: soon!
    '''
    
    if not '__eq__' in t.__dict__:
        t.__eq__ = lambda self, x: t.__cmp__(self, x) == 0
        t.__ne__ = lambda self, x: not t.__eq__(self, x)

    if not '__lt__' in t.__dict__:
        t.__lt__ = lambda self, x: t.__cmp__(self, x) < 0
    if not '__le__' in t.__dict__:
        t.__le__ = lambda self, x: t.__cmp__(self, x) <= 0

    if not '__gt__' in t.__dict__:
        t.__gt__ = lambda self, x: t.__cmp__(self, x) > 0
    if not '__ge__' in t.__dict__:
        t.__ge__ = lambda self, x: t.__cmp__(self, x) >= 0
    
    return t

CT = TypeVar('CT')

class Comparable(Protocol, Generic[CT]):
    def __cmp__(self, other: CT) -> int: ...

==> ufpy-0.3.0.1.tar.gz: ufpy-0.3.0.1/ufpy/cmp.py <==
"""
Module with generator compare magic methods
"""

__all__ = (
    'cmp_generator',
    'Comparable',
)

from typing import Protocol, Type, TypeVar

T = TypeVar('T', bound=type)

def cmp_generator(t: Type[T]) -> Type[T]:
    """
    Decorator for auto generate compare magic methods
    (`__eq__()`, `__ne__()`, `__lt__()`, `__le__()`, `__gt__()`, `__ge__()`).
    You should add `__cmp__()` method in your class. If your object more that other, `__cmp__()`
    should return positive number.
    If less that other, `__cmp__()` should return negative number. If equals, `__cmp__()` should return zero.

    `Note:`
    If you defined one of compare methods, they won't redefine.

    Example:
    ```py
    @cmp_generator
    class A:
        def __init__(self, num: int):
            self.num = num
        def __cmp__(self, other: int) -> int:
            return self.num - self.other

    a = A(2)
    print(a > 1) # True
    print(a < 2) # False
    print(a >= 3) # False
    print(a <= 4) # True
    ```

    Online docs: soon!
    """

    if  '__eq__' not in t.__dict__:
        t.__eq__ = lambda self, x: t.__cmp__(self, x) == 0
    if not '__ne__' in t.__dict__:
        t.__ne__ = lambda self, x: t.__cmp__(self, x) != 0

    if not '__lt__' in t.__dict__:
        t.__lt__ = lambda self, x: t.__cmp__(self, x) < 0
    if not '__le__' in t.__dict__:
        t.__le__ = lambda self, x: t.__cmp__(self, x) <= 0

    if not '__gt__' in t.__dict__:
        t.__gt__ = lambda self, x: t.__cmp__(self, x) > 0
    if not '__ge__' in t.__dict__:
        t.__ge__ = lambda self, x: t.__cmp__(self, x) >= 0

    return t

CT = TypeVar('CT')

class Comparable(Protocol[CT]): # pylint: disable=too-few-public-methods, missing-class-docstring
    def __cmp__(self, other: CT) -> int: ...
